@@ -19,7 +19,7 @@
  */
 
 #include "xapianqueryparser.h"
-
+#include "helper_p.h"
 #include <QTextBoundaryFinder>
 #include <QStringList>
 #include "akonadi_search_xapian_debug.h"
@@ -27,7 +27,7 @@
 using namespace Akonadi::Search;
 
 XapianQueryParser::XapianQueryParser()
-    : m_db(0)
+    : m_db(nullptr)
     , m_autoExpand(true)
 {
 }
@@ -87,7 +87,7 @@ Xapian::Query makeQuery(const QString &string, int position, Xapian::Database *d
     QVector<Xapian::Query> queries;
     queries.reserve(topTerms.size());
 
-    Q_FOREACH (const Term &term, topTerms) {
+    for (const Term &term : qAsConst(topTerms)) {
         queries << Xapian::Query(term.t, 1, position);
     }
 
@@ -100,7 +100,7 @@ Xapian::Query makeQuery(const QString &string, int position, Xapian::Database *d
 
 bool containsSpace(const QString &string)
 {
-    Q_FOREACH (const QChar &ch, string) {
+    for (const QChar &ch : string) {
         if (ch.isSpace()) {
             return true;
         }
@@ -189,7 +189,7 @@ Xapian::Query XapianQueryParser::parseQuery(const QString &text, const QString &
             // Remove all accents
             const QString denormalized = str.normalized(QString::NormalizationForm_KD);
             QString cleanString;
-            Q_FOREACH (const QChar &ch, denormalized) {
+            for (const QChar &ch : denormalized) {
                 auto cat = ch.category();
                 if (cat != QChar::Mark_NonSpacing && cat != QChar::Mark_SpacingCombining && cat != QChar::Mark_Enclosing) {
                     cleanString.append(ch);
@@ -197,7 +197,8 @@ Xapian::Query XapianQueryParser::parseQuery(const QString &text, const QString &
             }
 
             str = cleanString.normalized(QString::NormalizationForm_KC);
-            Q_FOREACH (const QString &t, str.split(QLatin1Char('_'), QString::SkipEmptyParts)) {
+            const QStringList lst = str.split(QLatin1Char('_'), QString::SkipEmptyParts);
+            for (const QString &t : lst) {
                 const QString term = prefix + t;
 
                 position++;
@@ -219,7 +220,6 @@ Xapian::Query XapianQueryParser::parseQuery(const QString &text, const QString &
     if (inPhrase) {
         queries << Xapian::Query(Xapian::Query::OP_PHRASE, phraseQueries.begin(), phraseQueries.end());
         phraseQueries.clear();
-        inPhrase = false;
     }
 
     if (!phraseQueries.isEmpty()) {
